@@ -10,6 +10,11 @@ class Image(object):
 	def __init__(self):	
 		a=1
 		#
+	def convert(self, input='logo.png', output='logo.ico'):
+		filename = input
+		img = _Image_.open(filename)
+		img.save(output)
+		print(f"Successfully converted image {input} to {output}.")
 	def replace_pixels(self, input_path=None, output_path=None, input_hex=None, output_hex=None):
 		img = _Image_.open(input_path)
 		pixels = img.load()
